%ODE file to calculate the steady state concentration of the 24 metabolites
function dydt = Pathway_ODE(t,y)
format shorte 

Parameter_Setting; % File containing all the kinetic parameters and the enzyme concentrations

%y(1)= phenylalanine(Phe)
%y(2) = Cinnamic Acid(CiA)
%y(3) = 4-Coumaric Acid(pA)
%y(4) = Caffeic Acid(CA)
%y(5) = Ferulic Acid(FA)
%y(6) = 5-Hydroxy Ferulic Acid(5HFA)
%y(7) = Sinapic Acid(SA)
%y(8) = 4-Coumaroyl CoA(pACoA)
%y(9) = 4-Coumaroyl shikimic Acid(pACoSA)
%y(10) = Caffeoyl ShikimicAacid (CaSA)
%y(11) = Caffeoyl-CoA (CACoa)
%y(12) = Feruloyl-CoA (FACoA)
%y(13) = 5-Hydroxy-feruloyl-CoA (5HFCoA)
%y(14) = Sinaloyl-CoA (SCoA)
%y(15) = 4-Coumaraldehyde(pAld)
%y(16) = Caffealdehyde(CAFAld)
%y(17) = Coniferaldehyde(CAld)
%y(18) = 5-Hydroxyconiferaldehyde(5HCAld)
%y(19) = Sinapaldehyde
%y(20) = 4-Coumaryl Alcohol(pAlc)
%y(21) = Caffeyl Alcohol (CAFAlc) 
%y(22) = Coniferyl Alcohol(CAlc)
%y(23) = 5-Hydroxy Coniferyl Alcohol (5HCAlc)
%y(24) = Sinapyl Alcohol (SAlc)

%%
%Definiton of Reaction Flux and the corresponding Enzymes
%V0 = Input Flux to phenylalanine
%V1 = Phe -> CiA; PtrPAL
%V2 = CiA -> pA; PtrC4H12
%V3 = pA -> CA; PtrC3H3
%V4 = CA -> FA; PtrCOMT2
%V5 = FA -> HFA; PtrCAld5H
%V6 = 5HFA -> SA; PtrCOMT2
%V7 = pA -> pACoA; Ptr4CL
%V8 = CA--->CACoA; Ptr4CL
%V9 = FA ---> FACoA; Ptr4CL
%V10 = HFA --->HFACoA; Ptr4CL
%V11 = SA ---> SCoA; Ptr4CL
%V12 = pCoCoA --> pCoSA; PtrHCT
%V13 = pCoSA --> CaSA; PtrC3H3
%V14 = CaSA -->CaCoA; PtrHCT
%V15 = CACoA --> FACoA; PtrCCoAOMT
%V16 = HFCoA --> SCoA; PtrCCoAOMT
%V17 = pCoA --> pCAld; PtrCCR2
%V18 = CACoA --> CAFAld; PtrCCR2
%V19 = FCoA --> CAld; PtrCCR2
%V20 = HFCoA --> HCAld; PtrCCR2
%V21 = SCoA --> SAld; PtrCCR2
%V22 = CAFAld --> CAld; PtrCOMT2
%V23 = CAld --> HCAld; PtrCAld5H
%V24 = 5HCAld -- > SAld; PtrCOMT2
%V25 = pAld-->pAlc; PtrCAD
%V26 = CAFAld --->CAFAlc; PtrCAD
%V27 = CAld --> CAlc; PtrCAD
%V28 = HCAld --> HCAlc; PtrCAD
%V29 = SAld--> SAlcl; PtrCAD
%V30 = CAFAlc --> CAlc; PtrCOMT
%V31 = CAlc --> HCAlc; PtrCAld5H
%V32 = 5HCAlc ---> SAlc; PtrCOMT2
%V33 = pAlc -> H lignin
%V34 = CAlc -> G lignin
%V25 = SAlc -> S lignin
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%% Reaction Flux represented by MM kinetics  %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

V0          =   0.904;
V1          =   (kcat11*PtrPAL1*y(1)/(y(1)*(1+y(4)/kiu1) + km11*(1 + y(2)/kic11 +  y(4)/kic111 ))) + ((kcat12*PtrPAL2*y(1))/(y(1)*(1+ + y(2)/kiu12...
                + y(4)/kiu121) + km12*(1 + y(2)/kic12 +  y(4)/kic121 ))) + ((kcat13*PtrPAL3*y(1))/(y(1)*(1+ y(2)/kiu13 + y(4)/kiu131) + km13*(1 + y(2)/kic13...
                + y(4)/kic131 ))) + ((kcat14*PtrPAL45*y(1))/(y(1)*(1+y(4)/kiu14) + km14*(1 + y(2)/kic14 +  y(4)/kic141)));
V2          =   (kcat2*PtrC4H12*y(2))/(y(2) + km2);
V3          =   (kcat3*PtrC3H3*y(3))/(y(3) + km3);
V4          =   (y(4)*kcat4*PtrCOMT2)/(y(4)*(1+(y(16)/kiu41) + (y(21)/kiu42) + (y(6)/kiu43)+ (y(18)/kiu44) + (y(23)/kiu45)) + km4*(1 +(y(16)/kic41)...
                + (y(21)/kic42) + (y(6)/kic43)+ (y(18)/kic44) + (y(23)/kic45)))  ;
V5          =   (y(5)*kcat51*PtrCAld5H1)/(y(5)*(1+(y(17)/kiu51) + km51*(1 +(y(17)/kic51)))) + (y(5)*kcat52*PtrCAld5H2)/(y(5)*(1+(y(17)/kiu52)...
                + km52*(1 +(y(17)/kic52))));
V6          =   (y(6)*kcat6*PtrCOMT2)/(y(6) + km6);
V7          =   (kcat71*Ptr4CL3*y(3)/((km71*(1+ (y(4)/k73c1) + (y(5)/k73c2) + (y(6)/k73c3) + (y(7)/k73c4))) + y(3))) + ...
                (kcat72*Ptr4CL5*y(3)/(y(3)*(1+ (y(4)/k75u1) + (y(5)/k75u2) + (y(6)/k75u3) + (y(7)/k75u4)) + km72*(1 + (y(4)/k75c1) + (y(5)/k75c2)...
                + (y(6)/k75c3)+ (y(7)/k75c4))));
V8          =   (kcat81*Ptr4CL3*y(4)/((km81*(1+ (y(3)/k83c1) + (y(5)/k83c2) + (y(6)/k83c3))+ y(4)))) +  (kcat82*Ptr4CL5*y(4)/((km82*(1+ (y(3)/k85c1)...
                + (y(5)/k85c2) + (y(6)/k85c3) + (y(7)/k85c4))+ y(4)*(1 + (y(3)/k85u1) + (y(5)/k85u2) + (y(6)/k85u3) + (y(7)/k85u4) + (y(4)/kis85)))));
V9          =   y(5)*kcat91*Ptr4CL3/((km91*(1 + (y(3)/k93c1) + (y(4)/k93c2) + (y(6)/k93c3) + (y(7)/k93c4))) + y(5)) +...
                (y(5)*kcat92*Ptr4CL5/(km92*(1 + (y(3)/k95c1) + (y(4)/k95c2) + (y(6)/k95c3) + (y(7)/k95c4)) + y(5)*(1 + (y(4)/k95u1) + (y(6)/k95u2)...
                + y(7)/k95u3)));
V10         =   (y(6)*kcat101*Ptr4CL3/(km101 + y(6))) +  (y(6)*kcat102*Ptr4CL5/(km102 + y(6)));
V11         =   (y(7)*kcat111*Ptr4CL5/(km111 + y(7)));
V12         =   y(8)*kcat121*PtrHCT1/(y(8) + km121) + y(8)*kcat122*PtrHCT6/(y(8) + km122);
V12R        =   y(9)*kcat121R*PtrHCT1/(y(9) + km121R) + y(9)*kcat122R*PtrHCT6/(y(9) + km122R);
V13         =   y(9)*kcat131*PtrC3H3/(y(9) + km131);
V14         =   y(10)*kcat141*PtrHCT1/(y(10) + km141)+ y(10)*kcat142*PtrHCT6/(y(10) + km142);
V14R        =   y(11)*kcat141R*PtrHCT1/(y(11) + km141R)+ y(11)*kcat142R*PtrHCT6/(y(11) + km142R);
V15         =   y(11)*kcat151*PtrCCoAOMT1/(y(11) + km151) + y(11)*kcat152*PtrCCoAOMT2/(y(11) + km152) + y(11)*kcat153*PtrCCoAOMT3/(y(11) + km153);
V16         =   0;
V17         =   (y(8)*PtrCCR2*kcat181/(y(8) + km181));
V18        =   (y(11)*PtrCCR2*kcat191)/(y(11) + km191);
V19         =   (y(12)*PtrCCR2*kcat201)/(y(12) + km201);
V20         =   0;
V21         =   0;
V22         =   (y(16)*kcat241*PtrCOMT2)/(y(16)*(1+(y(18)/kiu241) + (y(16)/kis241)) + km241*(1 +(y(4)/kic241) + (y(6)/kic242) + (y(18)/kic243)...
                + (y(23)/kic244)))  ;
V23         =   y(17)*PtrCAld5H1*kcat251/(y(17) + km251) + y(17)*PtrCAld5H2*kcat252/(y(17) + km252);
V24         =   y(18)*kcat261*PtrCOMT2/(y(18)*(1+(y(21)/kiu261) + (y(18)/kis261)) + km261*(1 +(y(16)/kic261) + (y(21)/kic262) +  (y(23)/kic263)));
V25         =   y(15)*45.89/(2.97+y(15));
V26         =   0;
V27         =   y(17)*kcat291*PtrCAD1/(y(17)*(1 + (y(19)/kiu291)) + km291*(1+ (y(19)/kic291))) + y(17)*kcat292*PtrCAD2/(y(17) + km292);
V28         =   0;
V29         =   y(19)*kcat311*PtrCAD1/(y(19)*(1 + (y(17)/kiu311)) + km311*(1+ (y(17)/kic311))) + y(19)*kcat312*PtrCAD2/(y(19) + km312);
V30         =   y(21)*kcat331*PtrCOMT2/(y(21)*(1+(y(16)/kiu331) + (y(18)/kiu332) + (y(23)/kiu333) +(y(21)/kis331)) + km331*(1 +(y(16)/kic331) + (y(18)/kic332)));
V31         =   y(22)*kcat341*PtrCAld5H1/(y(22)*(1 + y(17)/kiu341) + km341*(1 + y(17)/kic341)) + y(22)*kcat342*PtrCAld5H2/(y(22) + km342*(1 + y(17)/kic342));
V32         =   y(23)*kcat351*PtrCOMT2/(y(23)*(1 + y(23)/kis351 + y(21)/kis351) + km351);
V33         =   y(20);
V34         =   y(22);
V35         =   y(24);
%%
% Mass Balance on 24 Metabolites %

dydt(1)     =   V0 - V1; 
dydt(2)     =   V1 - V2;
dydt(3)     =   V2 - V3 - V7;
dydt(4)     =   V3 - V4 - V8;
dydt(5)     =   V4 - V5 - V9;
dydt(6)     =   V5 - V6 - V10;
dydt(7)     =   V6 - V11;
dydt(8)     =   V7 - V12 - V18; 
dydt(9)     =   V12 - V13;
dydt(10)    =   V13 - V14;
dydt(11)    =   V14 + V8 - V15 - V18;
dydt(12)    =   V15 + V9 - V19;
dydt(13)    =   V10 - V16 - V20;
dydt(14)    =   V11 + V16 - V21;
dydt(15)    =   V17 - V25;
dydt(16)    =   V18 - V22 - V26;
dydt(17)    =   V19 + V22 - V23 - V27;
dydt(18)    =   V23 + V20 - V24 - V28;
dydt(19)    =   V21 + V24 - V29;
dydt(20)    =   V25 - V33;
dydt(21)    =   V26 - V30;
dydt(22)    =   V30 + V27 - V31 - V34;
dydt(23)    =   V31 + V28 - V32;
dydt(24)    =   V29 + V32 - V35;

dydt=dydt(:); % Output as a column vector
end